#
#   LC filter Q table.
#   Copyright (C) 2009 2012 2013 2015 2017 2018  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "Q.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)
Xc(f,C)=1/(2*pi*f*C)
Xl(R,Q)=R*Q



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set logscale x
set logscale y

set samples 300

set xrange[0.001:1000]
set xtics 10
set mxtics 10

set yrange[0.001:1000]
set ytics 10
set mytics 10

set xlabel "R value [$\\Omega$]"
set ylabel "$X_L$ impedance [$\\Omega$]"
set title "Q table"


#set arrow 8 from 0.0012,0.12 to 1.2,0.12 lw 3
#set label 9 '$ \times 1000 $' at 0.03,0.14 front

set label 11 "0.001"      at    13,0.015 rotate by 34.0 front
set label 12 "0.1"        at   1.3,0.15  rotate by 34.0 front
set label 13 "10"         at  0.13,1.5   rotate by 34.0 front
set label 14 "1000"       at 0.013,15    rotate by 34.0 front

set label 16 "0.01"       at    13,0.15  rotate by 34.0 front
set label 17 "1"          at   1.3,1.5   rotate by 34.0 front
set label 18 "100"        at  0.13,15    rotate by 34.0 front

set object 1 rect from 50,0.01 to 1000,0.001 front lw 3
set label  2 '$ Q = \frac{X_L}{R} $' at 80,0.005 front
set label  3 '$ X_L \cdot 10^{-3} = j 2 \pi f L \cdot 10^{-3} $' at 80,0.0022 front

plot	Xl(x,  1e-3) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-3) axes x1y1 notitle lt 1, \
	Xl(x,  3e-3) axes x1y1 notitle lt 1, \
	Xl(x,  4e-3) axes x1y1 notitle lt 1, \
	Xl(x,  5e-3) axes x1y1 notitle lt 1, \
	Xl(x,  6e-3) axes x1y1 notitle lt 1, \
	Xl(x,  7e-3) axes x1y1 notitle lt 1, \
	Xl(x,  8e-3) axes x1y1 notitle lt 1, \
	Xl(x,  9e-3) axes x1y1 notitle lt 1, \
	Xl(x,  1e-3) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-3) axes x1y1 notitle lt 1, \
	Xl(x,  3e-3) axes x1y1 notitle lt 1, \
	Xl(x,  4e-3) axes x1y1 notitle lt 1, \
	Xl(x,  5e-3) axes x1y1 notitle lt 1, \
	Xl(x,  6e-3) axes x1y1 notitle lt 1, \
	Xl(x,  7e-3) axes x1y1 notitle lt 1, \
	Xl(x,  8e-3) axes x1y1 notitle lt 1, \
	Xl(x,  9e-3) axes x1y1 notitle lt 1, \
	Xl(x, 10e-3) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e-3) axes x1y1 notitle lt 1, \
	Xl(x, 30e-3) axes x1y1 notitle lt 1, \
	Xl(x, 40e-3) axes x1y1 notitle lt 1, \
	Xl(x, 50e-3) axes x1y1 notitle lt 1, \
	Xl(x, 60e-3) axes x1y1 notitle lt 1, \
	Xl(x, 70e-3) axes x1y1 notitle lt 1, \
	Xl(x, 80e-3) axes x1y1 notitle lt 1, \
	Xl(x, 90e-3) axes x1y1 notitle lt 1, \
	Xl(x,100e-3) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e-3) axes x1y1 notitle lt 1, \
	Xl(x,300e-3) axes x1y1 notitle lt 1, \
	Xl(x,400e-3) axes x1y1 notitle lt 1, \
	Xl(x,500e-3) axes x1y1 notitle lt 1, \
	Xl(x,600e-3) axes x1y1 notitle lt 1, \
	Xl(x,700e-3) axes x1y1 notitle lt 1, \
	Xl(x,800e-3) axes x1y1 notitle lt 1, \
	Xl(x,900e-3) axes x1y1 notitle lt 1, \
	Xl(x,  1e0 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  3e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  4e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  5e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  6e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  7e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  8e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  9e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 10e0 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 30e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 40e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 50e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 60e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 70e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 80e0 ) axes x1y1 notitle lt 1, \
	Xl(x, 90e0 ) axes x1y1 notitle lt 1, \
	Xl(x,100e0 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e0 ) axes x1y1 notitle lt 1, \
	Xl(x,300e0 ) axes x1y1 notitle lt 1, \
	Xl(x,400e0 ) axes x1y1 notitle lt 1, \
	Xl(x,500e0 ) axes x1y1 notitle lt 1, \
	Xl(x,600e0 ) axes x1y1 notitle lt 1, \
	Xl(x,700e0 ) axes x1y1 notitle lt 1, \
	Xl(x,800e0 ) axes x1y1 notitle lt 1, \
	Xl(x,900e0 ) axes x1y1 notitle lt 1, \
	Xl(x,  1e3 ) axes x1y1 notitle lt 1 lw 2

