#
#   Xc impedance table, reverted.
#   Copyright (C) 2009 2012 2013 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "Xc_rev.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)
Xc(f,C)=1/(2*pi*f*C)
Xl(f,L)=2*pi*f*L



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set samples 300

set logscale x
set format x '%.0s %cHz'
set xrange[10e0:100e9]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cHz'
set x2range[10e0:100e9]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %c$\Omega$'
set yrange[10e-3:10e3]
set ytics 10
set mytics 10

set tmargin 5
set title '$X_C$ impedance table, reverted\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'


set label 10 '1pF'      at  200e6,600    rotate by -50.0 front
set label 11 '10pF'     at  200e6,60     rotate by -50.0 front
set label 12 '100pF'    at   20e6,60     rotate by -50.0 front
set label 13 '1nF'      at   20e6,6      rotate by -50.0 front
set label 14 '10nF'     at    2e6,6      rotate by -50.0 front
set label 15 '100nF'    at    2e6,0.6    rotate by -50.0 front
set label 16 '1$\mu$F'  at  200e3,0.6    rotate by -50.0 front
set label 17 '10$\mu$F' at  200e3,0.06   rotate by -50.0 front


set object 1 rect from 10,0.1 to 1000,0.01 front lw 3
set label  2 '$ X_C = \frac{1}{j \omega C} = \frac{1}{j 2 \pi f C} $' at 20,0.05 front
set label  3 '$ \frac{1}{2 \pi \cdot 159 \cdot 10^6 Hz \cdot 1 \cdot 10^{-9}F} = 1 \Omega $' at 15,0.022 front

plot	Xc(x,  1e-12) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e-12) axes x1y1 notitle lt 1, \
	Xc(x,  3e-12) axes x1y1 notitle lt 1, \
	Xc(x,  4e-12) axes x1y1 notitle lt 1, \
	Xc(x,  5e-12) axes x1y1 notitle lt 1, \
	Xc(x,  6e-12) axes x1y1 notitle lt 1, \
	Xc(x,  7e-12) axes x1y1 notitle lt 1, \
	Xc(x,  8e-12) axes x1y1 notitle lt 1, \
	Xc(x,  9e-12) axes x1y1 notitle lt 1, \
	Xc(x, 10e-12) axes x1y1 notitle lt 1 lw 2, \
	Xc(x, 20e-12) axes x1y1 notitle lt 1, \
	Xc(x, 30e-12) axes x1y1 notitle lt 1, \
	Xc(x, 40e-12) axes x1y1 notitle lt 1, \
	Xc(x, 50e-12) axes x1y1 notitle lt 1, \
	Xc(x, 60e-12) axes x1y1 notitle lt 1, \
	Xc(x, 70e-12) axes x1y1 notitle lt 1, \
	Xc(x, 80e-12) axes x1y1 notitle lt 1, \
	Xc(x, 90e-12) axes x1y1 notitle lt 1, \
	Xc(x,100e-12) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,200e-12) axes x1y1 notitle lt 1, \
	Xc(x,300e-12) axes x1y1 notitle lt 1, \
	Xc(x,400e-12) axes x1y1 notitle lt 1, \
	Xc(x,500e-12) axes x1y1 notitle lt 1, \
	Xc(x,600e-12) axes x1y1 notitle lt 1, \
	Xc(x,700e-12) axes x1y1 notitle lt 1, \
	Xc(x,800e-12) axes x1y1 notitle lt 1, \
	Xc(x,900e-12) axes x1y1 notitle lt 1, \
	Xc(x,  1e-9 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  3e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  4e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  5e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  6e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  7e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  8e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  9e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 10e-9 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x, 20e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 30e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 40e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 50e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 60e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 70e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 80e-9 ) axes x1y1 notitle lt 1, \
	Xc(x, 90e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,100e-9 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,200e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,300e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,400e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,500e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,600e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,700e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,800e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,900e-9 ) axes x1y1 notitle lt 1, \
	Xc(x,  1e-6 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  3e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  4e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  5e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  6e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  7e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  8e-6 ) axes x1y1 notitle lt 1, \
	Xc(x,  9e-6 ) axes x1y1 notitle lt 1, \
	Xc(x, 10e-6 ) axes x1y1 notitle lt 1 lw 2


