#
#   Xc impedance table.
#   Copyright (C) 2009 2012 2013 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "Xc.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)
Xc(C,f)=1/(2*pi*f*C)
Xl(L,f)=2*pi*f*L



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set samples 300

set logscale x
set format x '%.0s %cF'
set xrange[1e-12:1e-6]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cF'
set x2range[1e-12:1e-6]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %c$\Omega$'
set yrange[10e-3:10e3]
set ytics 10
set mytics 10

set tmargin 5
set title '$X_C$ impedance table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2009 2012 2013 2015 2017 2018 2022\hspace{0.2cm} Alessandro Accattini'


set label 10 "1kHz"   at  200e-9,650    rotate by -36.0 front
set label 11 "100kHz" at   20e-9,65     rotate by -36.0 front
set label 12 "10MHz"  at    2e-9,6.5    rotate by -36.0 front
set label 13 "1GHz"   at  0.2e-9,0.65   rotate by -36.0 front

set label 15 "10kHz"  at  200e-9,65     rotate by -36.0 front
set label 16 "1MHz"   at   20e-9,6.5    rotate by -36.0 front
set label 17 "100MHz" at    2e-9,0.65   rotate by -36.0 front
set label 18 "10GHz"  at  0.2e-9,0.065  rotate by -36.0 front


set object 1 rect from 0.001e-9,0.1 to 0.02e-9,0.01 front lw 3
set label  2 '$ X_C = \frac{1}{j \omega C} = \frac{1}{j 2 \pi f C} $' at 0.0020e-9,0.05 front
set label  3 '$ \frac{1}{2 \pi \cdot 159 \cdot 10^6 Hz \cdot 1 \cdot 10^{-9}F} = 1 \Omega $' at 0.0015e-9,0.022 front

plot	Xc(x, 10e9 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  1e9 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  3e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  4e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  5e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  6e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  7e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  8e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  9e9 ) axes x1y1 notitle lt 1, \
	Xc(x,  1e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  3e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  4e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  5e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  6e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  7e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  8e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  9e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 10e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x, 20e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 30e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 40e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 50e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 60e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 70e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 80e6 ) axes x1y1 notitle lt 1, \
	Xc(x, 90e6 ) axes x1y1 notitle lt 1, \
	Xc(x,100e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,200e6 ) axes x1y1 notitle lt 1, \
	Xc(x,300e6 ) axes x1y1 notitle lt 1, \
	Xc(x,400e6 ) axes x1y1 notitle lt 1, \
	Xc(x,500e6 ) axes x1y1 notitle lt 1, \
	Xc(x,600e6 ) axes x1y1 notitle lt 1, \
	Xc(x,700e6 ) axes x1y1 notitle lt 1, \
	Xc(x,800e6 ) axes x1y1 notitle lt 1, \
	Xc(x,900e6 ) axes x1y1 notitle lt 1, \
	Xc(x,  1e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,  2e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  3e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  4e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  5e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  6e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  7e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  8e3 ) axes x1y1 notitle lt 1, \
	Xc(x,  9e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 10e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x, 20e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 30e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 40e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 50e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 60e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 70e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 80e3 ) axes x1y1 notitle lt 1, \
	Xc(x, 90e3 ) axes x1y1 notitle lt 1, \
	Xc(x,100e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xc(x,200e3 ) axes x1y1 notitle lt 1, \
	Xc(x,300e3 ) axes x1y1 notitle lt 1, \
	Xc(x,400e3 ) axes x1y1 notitle lt 1, \
	Xc(x,500e3 ) axes x1y1 notitle lt 1, \
	Xc(x,600e3 ) axes x1y1 notitle lt 1, \
	Xc(x,700e3 ) axes x1y1 notitle lt 1, \
	Xc(x,800e3 ) axes x1y1 notitle lt 1, \
	Xc(x,900e3 ) axes x1y1 notitle lt 1

