#
#   Xl impedance table, reverted.
#   Copyright (C) 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "Xl_rev.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)
Xc(f,C)=1/(2*pi*f*C)
Xl(f,L)=2*pi*f*L



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right

set samples 300

set logscale x
set format x '%.0s %cHz'
set xrange[10e0:100e9]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cHz'
set x2range[10e0:100e9]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %c$\Omega$'
set yrange[10e-3:10e3]
set ytics 10
set mytics 10

set tmargin 5
set title '$X_L$ impedance table, reverted\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'

set label 11 '10mH'       at   2e4,1500  rotate by 51.0 front
set label 12 '1mH'        at   2e4,150   rotate by 51.0 front
set label 13 '100$\mu$H'  at   2e5,150   rotate by 51.0 front
set label 14 '10$\mu$H'   at   2e5,15    rotate by 51.0 front
set label 15 '1$\mu$H'    at   2e6,15    rotate by 51.0 front
set label 16 '100nH'      at   2e6,1.5   rotate by 51.0 front
set label 17 '10nH'       at   2e7,1.5   rotate by 51.0 front
set label 18 '1nH'        at   2e7,0.15  rotate by 51.0 front
set label 19 '100pH'      at   2e8,0.15  rotate by 51.0 front
set label 20 '10pH'       at   2e9,0.15  rotate by 51.0 front
set label 21 '1pH'        at  2e10,0.15  rotate by 51.0 front

set object 1 rect from 10,1e3 to 4000,10e3 front lw 3
set label  2 '$ X_L = j \omega L = j 2 \pi f L $' at 40,5e3 front
set label  3 '$ \underbrace{2 \pi \cdot 159}_{10^3} \cdot 10^3 Hz \cdot 1 \cdot 10^{-6} H = 1 \Omega $' at 15,2.0e3 front

plot	Xl(x,  1e-12) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-12) axes x1y1 notitle lt 1, \
	Xl(x,  3e-12) axes x1y1 notitle lt 1, \
	Xl(x,  4e-12) axes x1y1 notitle lt 1, \
	Xl(x,  5e-12) axes x1y1 notitle lt 1, \
	Xl(x,  6e-12) axes x1y1 notitle lt 1, \
	Xl(x,  7e-12) axes x1y1 notitle lt 1, \
	Xl(x,  8e-12) axes x1y1 notitle lt 1, \
	Xl(x,  9e-12) axes x1y1 notitle lt 1, \
	Xl(x, 10e-12) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e-12) axes x1y1 notitle lt 1, \
	Xl(x, 30e-12) axes x1y1 notitle lt 1, \
	Xl(x, 40e-12) axes x1y1 notitle lt 1, \
	Xl(x, 50e-12) axes x1y1 notitle lt 1, \
	Xl(x, 60e-12) axes x1y1 notitle lt 1, \
	Xl(x, 70e-12) axes x1y1 notitle lt 1, \
	Xl(x, 80e-12) axes x1y1 notitle lt 1, \
	Xl(x, 90e-12) axes x1y1 notitle lt 1, \
	Xl(x,100e-12) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e-12) axes x1y1 notitle lt 1, \
	Xl(x,300e-12) axes x1y1 notitle lt 1, \
	Xl(x,400e-12) axes x1y1 notitle lt 1, \
	Xl(x,500e-12) axes x1y1 notitle lt 1, \
	Xl(x,600e-12) axes x1y1 notitle lt 1, \
	Xl(x,700e-12) axes x1y1 notitle lt 1, \
	Xl(x,800e-12) axes x1y1 notitle lt 1, \
	Xl(x,900e-12) axes x1y1 notitle lt 1, \
	Xl(x,  1e-9) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-9) axes x1y1 notitle lt 1, \
	Xl(x,  3e-9) axes x1y1 notitle lt 1, \
	Xl(x,  4e-9) axes x1y1 notitle lt 1, \
	Xl(x,  5e-9) axes x1y1 notitle lt 1, \
	Xl(x,  6e-9) axes x1y1 notitle lt 1, \
	Xl(x,  7e-9) axes x1y1 notitle lt 1, \
	Xl(x,  8e-9) axes x1y1 notitle lt 1, \
	Xl(x,  9e-9) axes x1y1 notitle lt 1, \
	Xl(x, 10e-9) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e-9) axes x1y1 notitle lt 1, \
	Xl(x, 30e-9) axes x1y1 notitle lt 1, \
	Xl(x, 40e-9) axes x1y1 notitle lt 1, \
	Xl(x, 50e-9) axes x1y1 notitle lt 1, \
	Xl(x, 60e-9) axes x1y1 notitle lt 1, \
	Xl(x, 70e-9) axes x1y1 notitle lt 1, \
	Xl(x, 80e-9) axes x1y1 notitle lt 1, \
	Xl(x, 90e-9) axes x1y1 notitle lt 1, \
	Xl(x,100e-9) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e-9) axes x1y1 notitle lt 1, \
	Xl(x,300e-9) axes x1y1 notitle lt 1, \
	Xl(x,400e-9) axes x1y1 notitle lt 1, \
	Xl(x,500e-9) axes x1y1 notitle lt 1, \
	Xl(x,600e-9) axes x1y1 notitle lt 1, \
	Xl(x,700e-9) axes x1y1 notitle lt 1, \
	Xl(x,800e-9) axes x1y1 notitle lt 1, \
	Xl(x,900e-9) axes x1y1 notitle lt 1, \
	Xl(x,  1e-6) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-6) axes x1y1 notitle lt 1, \
	Xl(x,  3e-6) axes x1y1 notitle lt 1, \
	Xl(x,  4e-6) axes x1y1 notitle lt 1, \
	Xl(x,  5e-6) axes x1y1 notitle lt 1, \
	Xl(x,  6e-6) axes x1y1 notitle lt 1, \
	Xl(x,  7e-6) axes x1y1 notitle lt 1, \
	Xl(x,  8e-6) axes x1y1 notitle lt 1, \
	Xl(x,  9e-6) axes x1y1 notitle lt 1, \
	Xl(x, 10e-6) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e-6) axes x1y1 notitle lt 1, \
	Xl(x, 30e-6) axes x1y1 notitle lt 1, \
	Xl(x, 40e-6) axes x1y1 notitle lt 1, \
	Xl(x, 50e-6) axes x1y1 notitle lt 1, \
	Xl(x, 60e-6) axes x1y1 notitle lt 1, \
	Xl(x, 70e-6) axes x1y1 notitle lt 1, \
	Xl(x, 80e-6) axes x1y1 notitle lt 1, \
	Xl(x, 90e-6) axes x1y1 notitle lt 1, \
	Xl(x,100e-6) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e-6) axes x1y1 notitle lt 1, \
	Xl(x,300e-6) axes x1y1 notitle lt 1, \
	Xl(x,400e-6) axes x1y1 notitle lt 1, \
	Xl(x,500e-6) axes x1y1 notitle lt 1, \
	Xl(x,600e-6) axes x1y1 notitle lt 1, \
	Xl(x,700e-6) axes x1y1 notitle lt 1, \
	Xl(x,800e-6) axes x1y1 notitle lt 1, \
	Xl(x,900e-6) axes x1y1 notitle lt 1, \
	Xl(x,  1e-3) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e-3) axes x1y1 notitle lt 1, \
	Xl(x,  3e-3) axes x1y1 notitle lt 1, \
	Xl(x,  4e-3) axes x1y1 notitle lt 1, \
	Xl(x,  5e-3) axes x1y1 notitle lt 1, \
	Xl(x,  6e-3) axes x1y1 notitle lt 1, \
	Xl(x,  7e-3) axes x1y1 notitle lt 1, \
	Xl(x,  8e-3) axes x1y1 notitle lt 1, \
	Xl(x,  9e-3) axes x1y1 notitle lt 1, \
	Xl(x, 10e-3) axes x1y1 notitle lt 1 lw 2

