#
#   Xl impedance table.
#   Copyright (C) 2009 2012 2013 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "Xl.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)
Xc(f,C)=1/(2*pi*f*C)
Xl(L,f)=2*pi*f*L



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right

set samples 300

set logscale x
set format x '%.0s %cH'
set xrange[1e-9:10e-3]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cH'
set x2range[1e-9:10e-3]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %c$\Omega$'
set yrange[10e-3:10e3]
set ytics 10
set mytics 10

set tmargin 5
set title '$X_L$ impedance table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2009 2012 2013 2015 2017 2018 2022\hspace{0.2cm} Alessandro Accattini'


set label 11 "100Hz"      at    20e-6,0.015 rotate by 40.0 front
set label 12 "10kHz"      at     2e-6,0.15  rotate by 40.0 front
set label 13 "1MHz"       at   0.2e-6,1.5   rotate by 40.0 front
set label 14 "100MHz"     at  0.02e-6,15    rotate by 40.0 front
set label 15 "10GHz"      at 0.002e-6,150   rotate by 40.0 front

set label 16 "1kHz"       at    20e-6,0.15  rotate by 40.0 front
set label 17 "100kHz"     at     2e-6,1.5   rotate by 40.0 front
set label 18 "10MHz"      at   0.2e-6,15    rotate by 40.0 front
set label 19 "1GHz"       at  0.02e-6,150   rotate by 40.0 front

set object 1 rect from 200e-6,0.10 to 10000e-6,0.01 front lw 3
set label  2 '$ X_L = j \omega L = j 2 \pi f L $' at 600e-6,0.05 front
set label  3 '$ 2 \pi \cdot 159 \cdot 10^3 Hz \cdot 1 \cdot 10^{-6} H = 1 \Omega $' at 240e-6,0.022 front

plot	Xl(x, 10e9 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  1e9 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  3e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  4e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  5e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  6e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  7e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  8e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  9e9 ) axes x1y1 notitle lt 1, \
	Xl(x,  1e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  3e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  4e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  5e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  6e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  7e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  8e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  9e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 10e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 30e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 40e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 50e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 60e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 70e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 80e6 ) axes x1y1 notitle lt 1, \
	Xl(x, 90e6 ) axes x1y1 notitle lt 1, \
	Xl(x,100e6 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e6 ) axes x1y1 notitle lt 1, \
	Xl(x,300e6 ) axes x1y1 notitle lt 1, \
	Xl(x,400e6 ) axes x1y1 notitle lt 1, \
	Xl(x,500e6 ) axes x1y1 notitle lt 1, \
	Xl(x,600e6 ) axes x1y1 notitle lt 1, \
	Xl(x,700e6 ) axes x1y1 notitle lt 1, \
	Xl(x,800e6 ) axes x1y1 notitle lt 1, \
	Xl(x,900e6 ) axes x1y1 notitle lt 1, \
	Xl(x,  1e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,  2e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  3e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  4e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  5e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  6e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  7e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  8e3 ) axes x1y1 notitle lt 1, \
	Xl(x,  9e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 10e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x, 20e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 30e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 40e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 50e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 60e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 70e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 80e3 ) axes x1y1 notitle lt 1, \
	Xl(x, 90e3 ) axes x1y1 notitle lt 1, \
	Xl(x,100e3 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e3 ) axes x1y1 notitle lt 1, \
	Xl(x,300e3 ) axes x1y1 notitle lt 1, \
	Xl(x,400e3 ) axes x1y1 notitle lt 1, \
	Xl(x,500e3 ) axes x1y1 notitle lt 1, \
	Xl(x,600e3 ) axes x1y1 notitle lt 1, \
	Xl(x,700e3 ) axes x1y1 notitle lt 1, \
	Xl(x,800e3 ) axes x1y1 notitle lt 1, \
	Xl(x,900e3 ) axes x1y1 notitle lt 1, \
	Xl(x,100e0 ) axes x1y1 notitle lt 1 lw 2, \
	Xl(x,200e0 ) axes x1y1 notitle lt 1, \
	Xl(x,300e0 ) axes x1y1 notitle lt 1, \
	Xl(x,400e0 ) axes x1y1 notitle lt 1, \
	Xl(x,500e0 ) axes x1y1 notitle lt 1, \
	Xl(x,600e0 ) axes x1y1 notitle lt 1, \
	Xl(x,700e0 ) axes x1y1 notitle lt 1, \
	Xl(x,800e0 ) axes x1y1 notitle lt 1, \
	Xl(x,900e0 ) axes x1y1 notitle lt 1

