#
#   AL coil table.
#   Copyright (C) 2009 2012 2013 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#


set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "al.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)

L(Al,N)=Al*(N**2)
Al(L,N)=L/(N**2)
N(Al,L)=sqrt(L/Al)




set grid xtics ytics
set grid mxtics mytics

set key on
#set key title '$A_L$ [nH/$N^2$]'
set key title '$A_L$'
set key Left reverse samplen 1 box lw 1
set key width 1 height 1
#set key top left
#set key bottom right
set key center right


set samples 300

set logscale x
set format x '%.0s %cH'
set xrange[1e-6:1e0]
set xtics 10
set mxtics 10
unset xlabel

set logscale y
set format y '%.0f sp'
set yrange[1:1000]
set ytics 10
set mytics 10
unset ylabel

set title "$A_L$ coil table"
set title '$A_L$ coil table\hspace{1.0cm} Copyright \copyright\hspace{0.2cm} 2009 2012 2013 2015 2017 2018 2022\hspace{0.2cm} Alessandro Accattini'

set label 1 '$ 5.7 nH/N^2 $'  at 0.06e-3,120 rotate by 34.0 front
set label 2 '$ 160 nH/N^2 $'  at 0.20e-3,40  rotate by 34.0 front
set label 3 '$ 1600 nH/N^2 $' at 0.20e-3,10  rotate by 34.0 front
set label 4 '$ 5700 nH/N^2 $' at    7e-3,40  rotate by 34.0 front

set object 5 rect from 100e-3,8 to 1000e-3,1 front lw 3
set label  6 '$ L = A_L \cdot N^2 $' at 200e-3,5 front
set label  8 '$ A_L = \frac{L}{N^2} $' at 200e-3,3 front
set label  9 '$ N = \sqrt{\frac{L}{A_L}} $' at 200e-3,1.8 front

plot	N( 5.7e-9,x) axes x1y1 title "5.7"  lt 1 lw 3, \
	N( 160e-9,x) axes x1y1 title "160"  lt 1 lw 1, \
	N( 220e-9,x) axes x1y1 title "220"  lt 1 lw 2, \
	N( 250e-9,x) axes x1y1 title "250"  lt 1 lw 1, \
	N( 315e-9,x) axes x1y1 title "315"  lt 1 lw 1, \
	N( 400e-9,x) axes x1y1 title "400"  lt 1 lw 3, \
	N( 630e-9,x) axes x1y1 title "630"  lt 1 lw 2, \
	N(1000e-9,x) axes x1y1 title "1000" lt 1 lw 1, \
	N(1250e-9,x) axes x1y1 title "1250" lt 1 lw 2, \
	N(1600e-9,x) axes x1y1 title "1600" lt 1 lw 1, \
	N(5700e-9,x) axes x1y1 title "5700" lt 1 lw 1


