#
#   Versamento di carica da un condensatore ad un altro.
#   Copyright (C) 2018 2019 2021 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#


set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "capacitors.tex"




# Funzioni

K(C1,C2)=C1/(C1+C2)
Ref(x)=1e0/(1e1*x)



set grid xtics ytics
set grid mxtics mytics


set key on
set key title '$C_1$'
set key Left reverse samplen 1 box lw 1
set key width 1 height 1
set key right


set samples 300

set logscale x
set format x '%.0s %cF'
set xrange[10e-12:1e-6]
set xtics 10
set mxtics 10
set xlabel "$C_2$"

set logscale y
set format y '$10^{%T}$'
set yrange[1e-4:1]
set ytics 10
set mytics 10
set ylabel "$K$"


set title 'Versamento di carica da un condensatore ad un altro\hspace{1.0cm} Copyright \copyright\hspace{0.2cm} 2018 2019 2021 2022\hspace{0.2cm} Alessandro Accattini'

set object 1 rect from 0.01e-9,1e-2 to 1e-9,1e-14 front lw 3
set label 5 at 0.1e-9,3e-3 '\includegraphics[width=6.0cm]{capacitors.eps}' center front
set label 4 '$ Q = C \cdot V \qquad W = \frac{1}{2} \cdot C \cdot V^2 $' at 0.1e-9,8e-4 center front
set label 6 '$ v(t) = \frac{q(t)}{C} \qquad i(t) = \frac{\mathrm{d} q(t)}{\mathrm{d} t} = C \frac{\mathrm{d} v(t)}{\mathrm{d} t} $' at 0.1e-9,5e-4 center front
set label 2 '$ V_{1,2_{fin}} = \frac{C_1 \cdot V_{1_{ini}} + C_2 \cdot V_{2_{ini}}}{C_1 + C_2} \qquad V_{1,2_{fin}} = V_{1_{ini}} \underbrace{\frac{C_1}{C_1 + C_2}}_K $' at 0.1e-9,2.5e-4 center front
set label 3 '$ C_2 = C_1 \cdot \frac{V_{fin} - V_{1_{ini}}}{V_{2_{ini}} - V_{fin}}$' at 0.1e-9,1.5e-4 center front


plot	K(100e-12,x) title "100pF" with lines lw 3, \
	K(150e-12,x) title "150pF" with lines lw 4, \
	K(200e-12,x) title "200pF" with lines lw 4, \
	Ref(x) notitle with lines lw 1


