#
#   Common mode input low-pass filter.
#   Copyright (C) 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "com_lp.tex"



# Net 1:
#
#         Z5
# Vin o---Z---+---o Vout
#             |
#             Z Z6
#             |
#            GND
#

w(f)=2*pi*f
dB(v)=20*log10(v)

Zl(w,L)=w*L*{0,1}
Zc(w,C)=1/({0,1}*w*C)
Par(Z1,Z2)=Z1*Z2/(Z1+Z2)


Net_1(Z5,Z6)=Z6 / (Z5+Z6)


Com_LP(w,L,C)=Net_1(Zl(w,2.0*L),Zc(w,C))
Com_LCR(w,L,C,R)=Net_1(Zl(w,2.0*L),Par(Zc(w,C),R))



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set samples 300

set logscale x
set format x '%.0s %cHz'
set xrange[10e0:100e9]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cHz'
set x2range[10e0:100e9]
set x2tics 10
set mx2tics 10

set format y '%.0f dB'
set yrange[-120:10]
set ytics 10
set mytics 3

set title 'Common mode input filter gain\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'


set label 11 '$ LC=1 \cdot 10^{-15} \qquad C=1nF \qquad L=1\mu H \qquad R=100 \Omega \qquad L/C=10^3 $'      at   32e6,-35  rotate by -65.0 front
set label 12 '$ LC=10 \cdot 10^{-15} \qquad C=1nF \qquad L=10\mu H \qquad R=100 \Omega \qquad L/C=10^4 $'    at   10e6,-35  rotate by -65.0 front
set label 13 '$ LC=100 \cdot 10^{-15} \qquad C=10nF \qquad L=10\mu H \qquad R=100 \Omega \qquad L/C=10^3 $'  at  3.2e6,-35  rotate by -65.0 front
set label 14 '$ LC=1 \cdot 10^{-12} \qquad C=10nF \qquad L=100\mu H \qquad R=100 \Omega \qquad L/C=10^4 $'   at  1.0e6,-35  rotate by -65.0 front
set label 15 '$ LC=10 \cdot 10^{-12} \qquad C=100nF \qquad L=100\mu H \qquad R=100 \Omega \qquad L/C=10^3 $' at  320e3,-35  rotate by -65.0 front
set label 16 '$ LC=100 \cdot 10^{-12} \qquad C=100nF \qquad L=1mH \qquad R=100 \Omega \qquad L/C=10^4 $'     at  100e3,-35  rotate by -65.0 front
set label 17 '$ LC=1 \cdot 10^{-9} \qquad C=1 \mu F \qquad L=1mH \qquad R=100 \Omega \qquad L/C=10^3 $'      at   32e3,-35  rotate by -65.0 front
set label 18 '$ LC=10 \cdot 10^{-9} \qquad C=1 \mu F \qquad L=10mH \qquad R=100 \Omega \qquad L/C=10^4 $'    at   10e3,-35  rotate by -65.0 front
set label 19 '$ LC=100 \cdot 10^{-9} \qquad C=10 \mu F \qquad L=10mH \qquad R=100 \Omega \qquad L/C=10^3 $'  at  3.2e3,-35  rotate by -65.0 front

set object 1 rect from 1e9,10 to 100e9,-70 front lw 3
set label  2 '$ f_T = \frac{1}{2\pi\sqrt{2LC}} $' at 4e9,5 front
set label  4 '$ Z_{11}=Z_{22}=Z_m=j\omega L $' at 2e9,-15 front
set label  5 '$ L $ is nominal value' at 2e9,-25 front
set label  6 '$ \left[ \begin{array}{c} v_1 \\ v_2 \end{array} \right] = \left[ \begin{array}{cc} Z_{11} & Z_m \\ Z_m & Z_{22} \end{array} \right] \cdot \left[ \begin{array}{c} i_1 \\ i_2 \end{array} \right] $' at 2e9,-35 front
set object 8 rect from 10e6,10 to 1e9,0 front lw 3
set label  9 '$ |\frac{v_{out}}{v_{in}}|_{\omega=\omega_T} = R \cdot \sqrt{\frac{C}{L}} $' at 20e6,5 front
set object 10 rect from 10,-70 to 10000,-120 front lw 3


#			     L      C       R
plot	dB(abs(Com_LCR(w(x),  1e-6,  1e-9,200e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-6,  1e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-6,  1e-9, 50e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-6,  1e-9, 30e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-6,  1e-9, 20e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x), 10e-6,  1e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x), 10e-6, 10e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),100e-6, 10e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),100e-6,100e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-3,100e-9,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x),  1e-3,  1e-6,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x), 10e-3,  1e-6,100e0))) notitle lt 1 lw 2, \
	dB(abs(Com_LCR(w(x), 10e-3, 10e-6,100e0))) notitle lt 1 lw 2




