#
#   Copper resistance table.
#   Copyright (C) 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "cu.tex"



# Funzioni
R(ro,l,S)=ro*l/(S*1e-6)
f(ro,l,S,C)=1/(2.0*pi*2.0*R(ro,l,S)*C)



set grid xtics ytics
set grid mxtics mytics

#set key off
set key on
set key title "Wires"
set key Left reverse samplen 1 box lw 1
set key width 1 height 1
set key outside center right

set samples 300

set logscale x
set xrange[1:10]
set xtics (1,1.5,2,2.5,3,4,5,6,7,8,9,10)
set format x '%g$m$'

set logscale x2
set x2range[1:10]
set x2tics (1,1.5,2,2.5,3,4,5,6,7,8,9,10)
set format x2 '%g$m$'

set logscale y
set format y '%.0s %c$\Omega$'
set yrange[1e-3:1e1]
set ytics 10
set mytics 10

#set label 1 "10Hz"   at    60,200   rotate by -34.0 front
#set label 2 "100Hz"  at    30,40    rotate by -34.0 front
#set label 3 "1kHz"   at     6,20    rotate by -34.0 front
#set label 4 "10kHz"  at     3,4     rotate by -34.0 front
#set label 5 "100kHz" at   0.6,2     rotate by -34.0 front
#set label 6 "1MHz"   at   0.3,0.4   rotate by -34.0 front
#set label 7 "10MHz"  at  0.06,0.2   rotate by -34.0 front
#set label 8 "100MHz" at  0.03,0.04  rotate by -34.0 front

#set arrow  10 from 0.0012,12 to 1.2,12 lw 3
#set label  11 '$ \times 1000 $' at 0.03,14 front

#set object 12 rect from 0.001,0.01 to 0.02,0.001 front lw 3
#set label  13 '$ f_T = \frac{1}{2 \pi R C} $' at 0.0030,0.005 front
#set label  14 '$ \frac{1}{2 \pi \cdot 1 \cdot 10^3 \cdot 1 \cdot 10^{-9}} = 0.159 \cdot 10^6 $' at 0.0015,0.002 front

set tmargin 5
set title '$Cu$ wires table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'

plot	R(1.72e-8,x,0.0503) title "AWG 30, $0.0503mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.0646) title "AWG 29, $0.0646mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.0804) title "AWG 28, $0.0804mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.1020) title "AWG 27, $0.1020mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.1280) title "AWG 26, $0.1280mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.1630) title "AWG 25, $0.1630mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.2050) title "AWG 24, $0.2050mm^2$" lt 1 lw 2, \
	R(1.72e-8,x,0.2590) title "AWG 23, $0.2590mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.3250) title "AWG 22, $0.3250mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.4120) title "AWG 21, $0.4120mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.5000) title "$0.50mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,0.5190) title "AWG 20, $0.5190mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.6530) title "AWG 19, $0.6530mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,0.7500) title "$0.75mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,0.8230) title "AWG 18, $0.8230mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,1.0000) title "$1.00mm^2$"           lt 1 lw 3, \
	R(1.72e-8,x,1.0400) title "AWG 17, $1.0400mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,1.3100) title "AWG 16, $1.3100mm^2$" lt 1 lw 1, \
	R(1.72e-8,x,1.5000) title "$1.50mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,1.6500) title "AWG 15, $1.650mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,2.0800) title "AWG 14, $2.080mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,2.5000) title "$2.50mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,2.6300) title "AWG 13, $2.630mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,3.3100) title "AWG 12, $3.310mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,4.0000) title "$4.00mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,4.1500) title "AWG 11, $4.150mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,5.2700) title "AWG 10, $5.270mm^2$"  lt 1 lw 1, \
	R(1.72e-8,x,6.0000) title "$6.00mm^2$"           lt 1 lw 2, \
	R(1.72e-8,x,6.6200) title "AWG 9, $6.620mm^2$"   lt 1 lw 1



