#
#   LC filter table.
#   Copyright (C) 2009 2012 2013 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#


set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "lc.tex"



# Funzioni
f(L,C)=1/(2*pi*sqrt(L*C))
C(f,L)=1/(L*(2*pi*f)**2)
L(f,C)=1/(C*(2*pi*f)**2)



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set samples 300

set logscale x
set format x '%.0s %cH'
set xrange[1e-9:1e-3]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cH'
set x2range[1e-9:1e-3]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %cF'
set yrange[1e-12:1e-6]
set ytics 10
set mytics 10

set tmargin 5
set title 'LC filter table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2009 2012 2013 2015 2017 2018 2022\hspace{0.2cm} Alessandro Accattini'


set arrow 1 from 0.0015e-6,1.2e-9 to 0.0015e-6,120e-9 lw 2
set label 2 "$Q_{par}$" at 0.0013e-6,5e-9 rotate by 90.0 front

set arrow 3 from 1.2e-6,0.0015e-9 to 120e-6,0.0015e-9 lw 2
set label 4 "$Q_{ser}$" at 5e-6,0.0018e-9 front

set label 5 "10kHz"  at    200e-6,900e-9   rotate by -34.0 front
set label 6 "100kHz" at     20e-6,90e-9    rotate by -34.0 front
set label 7 "1MHz"   at      2e-6,9e-9     rotate by -34.0 front
set label 8 "10MHz"  at    0.2e-6,0.9e-9   rotate by -34.0 front
set label 9 "100MHz" at   0.02e-6,0.09e-9  rotate by -34.0 front
set label 10 "1GHz"  at 0.0011e-6,0.018e-9 rotate by -34.0 front

set object 11 rect from 0.001e-6,0.010e-9 to 0.02e-6,0.001e-9 front lw 3
set label  12 '$ f_T = \frac{1}{2 \pi \sqrt{LC} } $' at 0.003e-6,0.005e-9 front
set label  13 '$ \frac{1}{2 \pi \sqrt{1 \cdot 10^{-6} \cdot 1 \cdot 10^{-9}} } = 5.03 \cdot 10^6 $' at 0.0013e-6,0.002e-9 front


plot	C( 10e3,x) title "10kHz" lt 1 lw 2, \
	C( 20e3,x) notitle lt 1 lw 1, \
	C( 30e3,x) notitle lt 1 lw 1, \
	C( 40e3,x) notitle lt 1 lw 1, \
	C( 50e3,x) notitle lt 1 lw 1, \
	C( 60e3,x) notitle lt 1 lw 1, \
	C( 70e3,x) notitle lt 1 lw 1, \
	C( 80e3,x) notitle lt 1 lw 1, \
	C( 90e3,x) notitle lt 1 lw 1, \
	C(100e3,x) title "100kHz" lt 1 lw 2, \
	C(200e3,x) notitle lt 1 lw 1, \
	C(300e3,x) notitle lt 1 lw 1, \
	C(400e3,x) notitle lt 1 lw 1, \
	C(500e3,x) notitle lt 1 lw 1, \
	C(600e3,x) notitle lt 1 lw 1, \
	C(700e3,x) notitle lt 1 lw 1, \
	C(800e3,x) notitle lt 1 lw 1, \
	C(900e3,x) notitle lt 1 lw 1, \
	C(  1e6,x) title "1MHz" lt 1 lw 2, \
	C(  2e6,x) notitle lt 1 lw 1, \
	C(  3e6,x) notitle lt 1 lw 1, \
	C(  4e6,x) notitle lt 1 lw 1, \
	C(  5e6,x) notitle lt 1 lw 1, \
	C(  6e6,x) notitle lt 1 lw 1, \
	C(  7e6,x) notitle lt 1 lw 1, \
	C(  8e6,x) notitle lt 1 lw 1, \
	C(  9e6,x) notitle lt 1 lw 1, \
	C( 10e6,x) title "10MHz" lt 1 lw 2, \
	C( 20e6,x) notitle lt 1 lw 1, \
	C( 30e6,x) notitle lt 1 lw 1, \
	C( 40e6,x) notitle lt 1 lw 1, \
	C( 50e6,x) notitle lt 1 lw 1, \
	C( 60e6,x) notitle lt 1 lw 1, \
	C( 70e6,x) notitle lt 1 lw 1, \
	C( 80e6,x) notitle lt 1 lw 1, \
	C( 90e6,x) notitle lt 1 lw 1, \
	C(100e6,x) title "100MHz" lt 1 lw 2, \
	C(200e6,x) notitle lt 1 lw 1, \
	C(300e6,x) notitle lt 1 lw 1, \
	C(400e6,x) notitle lt 1 lw 1, \
	C(500e6,x) notitle lt 1 lw 1, \
	C(600e6,x) notitle lt 1 lw 1, \
	C(700e6,x) notitle lt 1 lw 1, \
	C(800e6,x) notitle lt 1 lw 1, \
	C(900e6,x) notitle lt 1 lw 1, \
	C(  1e9,x) title "1GHz" lt 1 lw 2


