#
#   Resistor power dissipation.
#   Copyright (C) 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "power.tex"



V(I,P)=P/I
r(P)=V(0.150,P)*1.1



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key bottom left


set samples 300

set logscale x
set format x '%.0s %cA'
set xrange[1e-3:10e0]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %cA'
set x2range[1e-3:10e0]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %cV'
set yrange[10e-3:100e0]
set ytics 10
set mytics 10

set logscale y2
set format y2 '%.0s %cV'
set y2range[10e-3:100e0]
set y2tics 10
set my2tics 10


set title 'Resistor power dissipation'

set tmargin 5
set title 'Resistor power dissipation\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'

set label 10 '$ 3W $'                     at 0.15,r(3)      rotate by -36.0 front
set label 11 '$ 1W \qquad $ case 2512'    at 0.15,r(1)      rotate by -36.0 front
set label 12 '$ 3/4W \qquad $ case 2010'  at 0.15,r(0.75)   rotate by -36.0 front
set label 13 '$ 1/2W \qquad $ case 1210'  at 0.15,r(0.50)   rotate by -36.0 front
set label 14 '$ 1/4W \qquad $ case 1206'  at 0.15,r(0.25)   rotate by -36.0 front
set label 15 '$ 1/8W \qquad $ case 0805'  at 0.15,r(0.125)  rotate by -36.0 front
set label 16 '$ 1/10W \qquad $ case 0603' at 0.15,r(0.10)   rotate by -36.0 front
set label 17 '$ 1/16W \qquad $ case 0402' at 0.15,r(1.0/16) rotate by -36.0 front
set label 18 '$ 1/20W \qquad $ case 0201' at 0.15,r(0.050)  rotate by -36.0 front

set object 1 rect from 1,100 to 10,10 front lw 3
set label  2 '$ P = V \cdot I = R \cdot I^2 = \frac{V^2}{R} $' at 1.5,45 front
set label  3 '$ 1W = 1V \cdot 1A $' at 2,20 front


plot	V(x,3.0)      notitle lt 1 lw 2, \
	V(x,1.0)      notitle lt 1 lw 2, \
	V(x,3.0/ 4.0) notitle lt 1 lw 2, \
	V(x,1.0/ 2.0) notitle lt 1 lw 2, \
	V(x,1.0/ 4.0) notitle lt 1 lw 2, \
	V(x,1.0/ 8.0) notitle lt 1 lw 2, \
	V(x,1.0/10.0) notitle lt 1 lw 2, \
	V(x,1.0/16.0) notitle lt 1 lw 2, \
	V(x,1.0/20.0) notitle lt 1 lw 2


