#
#   RC filter table.
#   Copyright (C) 2009 2015 2017 2018 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "rc.tex"



# Funzioni
f(R,C)=1/(2*pi*R*C)
R(f,C)=1/(2*pi*f*C)
C(R,f)=1/(2*pi*R*f)



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key bottom left


set samples 300

set logscale x
set format x '%.0s %c$\Omega$'
set xrange[1e0:1e6]
set xtics 10
set mxtics 10

set logscale x2
set format x2 '%.0s %c$\Omega$'
set x2range[1e0:1e6]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %cF'
set yrange[1e-12:1e-6]
set ytics 10
set mytics 10

set tmargin 5
set title 'RC filter table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2009 2015 2017 2018 2022\hspace{0.2cm} Alessandro Accattini'


set label 1 "10Hz"   at    60e3,200e-9   rotate by -34.0 front
set label 2 "100Hz"  at    30e3,40e-9    rotate by -34.0 front
set label 3 "1kHz"   at     6e3,20e-9    rotate by -34.0 front
set label 4 "10kHz"  at     3e3,4e-9     rotate by -34.0 front
set label 5 "100kHz" at   0.6e3,2e-9     rotate by -34.0 front
set label 6 "1MHz"   at   0.3e3,0.4e-9   rotate by -34.0 front
set label 7 "10MHz"  at  0.06e3,0.2e-9   rotate by -34.0 front
set label 8 "100MHz" at  0.03e3,0.04e-9  rotate by -34.0 front

#set arrow  10 from 0.0012,12 to 1.2,12 lw 3
#set label  11 '$ \times 1000 $' at 0.03,14 front

set object 12 rect from 0.001e3,0.01e-9 to 0.02e3,0.001e-9 front lw 3
set label  13 '$ f_T = \frac{1}{2 \pi R C} $' at 0.0030e3,0.005e-9 front
set label  14 '$ \frac{1}{2 \pi \cdot 1 \cdot 10^3 \cdot 1 \cdot 10^{-9}} = 159 \cdot 10^3 $' at 0.0015e3,0.002e-9 front

plot	C(x,10.0)  title "10Hz" lt 1 lw 2, \
	C(x,20.0)  notitle lt 1 lw 1, \
	C(x,30.0)  notitle lt 1 lw 1, \
	C(x,40.0)  notitle lt 1 lw 1, \
	C(x,50.0)  notitle lt 1 lw 1, \
	C(x,60.0)  notitle lt 1 lw 1, \
	C(x,70.0)  notitle lt 1 lw 1, \
	C(x,80.0)  notitle lt 1 lw 1, \
	C(x,90.0)  notitle lt 1 lw 1, \
	C(x,100.0) title "100Hz" lt 1 lw 2, \
	C(x,200.0) notitle lt 1 lw 1, \
	C(x,300.0) notitle lt 1 lw 1, \
	C(x,400.0) notitle lt 1 lw 1, \
	C(x,500.0) notitle lt 1 lw 1, \
	C(x,600.0) notitle lt 1 lw 1, \
	C(x,700.0) notitle lt 1 lw 1, \
	C(x,800.0) notitle lt 1 lw 1, \
	C(x,900.0) notitle lt 1 lw 1, \
	C(x,1e3)   title "1kHz" lt 1 lw 2, \
	C(x,2e3)   notitle lt 1 lw 1, \
	C(x,3e3)   notitle lt 1 lw 1, \
	C(x,4e3)   notitle lt 1 lw 1, \
	C(x,5e3)   notitle lt 1 lw 1, \
	C(x,6e3)   notitle lt 1 lw 1, \
	C(x,7e3)   notitle lt 1 lw 1, \
	C(x,8e3)   notitle lt 1 lw 1, \
	C(x,9e3)   notitle lt 1 lw 1, \
	C(x,10e3)  title "10kHz" lt 1 lw 2, \
	C(x,20e3)  notitle lt 1 lw 1, \
	C(x,30e3)  notitle lt 1 lw 1, \
	C(x,40e3)  notitle lt 1 lw 1, \
	C(x,50e3)  notitle lt 1 lw 1, \
	C(x,60e3)  notitle lt 1 lw 1, \
	C(x,70e3)  notitle lt 1 lw 1, \
	C(x,80e3)  notitle lt 1 lw 1, \
	C(x,90e3)  notitle lt 1 lw 1, \
	C(x,100e3) title "100kHz" lt 1 lw 2, \
	C(x,200e3) notitle lt 1 lw 1, \
	C(x,300e3) notitle lt 1 lw 1, \
	C(x,400e3) notitle lt 1 lw 1, \
	C(x,500e3) notitle lt 1 lw 1, \
	C(x,600e3) notitle lt 1 lw 1, \
	C(x,700e3) notitle lt 1 lw 1, \
	C(x,800e3) notitle lt 1 lw 1, \
	C(x,900e3) notitle lt 1 lw 1, \
	C(x,1e6)   title "1MHz" lt 1 lw 2, \
	C(x,2e6)   notitle lt 1 lw 1, \
	C(x,3e6)   notitle lt 1 lw 1, \
	C(x,4e6)   notitle lt 1 lw 1, \
	C(x,5e6)   notitle lt 1 lw 1, \
	C(x,6e6)   notitle lt 1 lw 1, \
	C(x,7e6)   notitle lt 1 lw 1, \
	C(x,8e6)   notitle lt 1 lw 1, \
	C(x,9e6)   notitle lt 1 lw 1, \
	C(x,10e6)  title "10MHz" lt 1 lw 2, \
	C(x,20e6)  notitle lt 1 lw 1, \
	C(x,30e6)  notitle lt 1 lw 1, \
	C(x,40e6)  notitle lt 1 lw 1, \
	C(x,50e6)  notitle lt 1 lw 1, \
	C(x,60e6)  notitle lt 1 lw 1, \
	C(x,70e6)  notitle lt 1 lw 1, \
	C(x,80e6)  notitle lt 1 lw 1, \
	C(x,90e6)  notitle lt 1 lw 1, \
	C(x,100e6) title "100MHz" lt 1 lw 2

