#
#   Timer utilizzato come generatore di frequenza.
#   Copyright (C) 2022  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#
#

set terminal epslatex standalone monochrome blacktext size 29.7cm,21.0cm
set output "timer.tex"



# Funzioni
fOCnA(fclk,N,OCRnA)=fclk/(2.0*N*(OCRnA+1.0))
fmin(fclk,N)=fOCnA(fclk,N,255.0)
OCRnA__(fclk,N,fOCnA)=(fclk/(2.0*N*fOCnA)-1.0)
OCRnA(fclk,N,fOCnA)=(OCRnA__(fclk,N,fOCnA) >= 1) ? OCRnA__(fclk,N,fOCnA) : 1.0/0
DfOC(fclk,N,f)=f*(1.0-(fclk/(fclk+2.0*N*f)))



set grid xtics ytics
set grid mxtics mytics

set key off
#set key on
#set key title "Lines"
#set key Left reverse samplen 1 box lw 1
#set key width 1 height 1
#set key top right


set samples 300

set logscale x
set format x '%.0s %cHz'
set xrange[1e0:10e6]
set xtics 10
set mxtics 10
set xlabel '$f_{OC}$'

set logscale x2
set format x2 '%.0s %cHz'
set x2range[1e0:10e6]
set x2tics 10
set mx2tics 10

set logscale y
set format y '%.0s %c'
set yrange[1e-3:100e3]
set ytics 10
set mytics 10
set ylabel '$OCR$'

set logscale y2
set format y2 '%.0s %cHz'
set y2range[1e-3:100e3]
set y2tics 10
set my2tics 10
set y2label '$\Delta f_{OC}$'


#set style fill transparent solid 0.10 noborder
set style fill transparent pattern 4 noborder


set tmargin 5
set title 'AVR frequency generators table\hspace{2.0cm} Copyright \copyright\hspace{0.2cm} 2022\hspace{0.2cm} Alessandro Accattini'


set label 1  '$OCR_n \qquad N=1$'            at 100e3,55e0  rotate by -34.0 front
set label 3  '$OCR_n \qquad N=8$'            at  60e3,10e0  rotate by -34.0 front
set label 5  '$OCR_n \qquad N=64$'           at   8e3,9e0   rotate by -34.0 front
set label 7  '$OCR_n \qquad N=256$'          at 100e0,200e0 rotate by -34.0 front
set label 9  '$OCR_n \qquad N=1024$'         at  40e0,130e0 rotate by -34.0 front
set label 2  '$\Delta f_{OC} \qquad N=1$'    at 400e0,60e-3 rotate by  52.0 front
set label 4  '$\Delta f_{OC} \qquad N=8$'    at 130e0,50e-3 rotate by  52.0 front
set label 6  '$\Delta f_{OC} \qquad N=64$'   at  43e0,45e-3 rotate by  52.0 front
set label 8  '$\Delta f_{OC} \qquad N=256$'  at  23e0,50e-3 rotate by  52.0 front
set label 10 '$\Delta f_{OC} \qquad N=1024$' at  11e0,50e-3 rotate by  52.0 front

set object 11 rect from 100e3,300e-3 to 10e6,1e-3 front lw 3

set arrow 20 from fmin(8e6,   1e0),80e3 to fmin(8e6,   1e0),300
set arrow 21 from fmin(8e6,   8e0),80e3 to fmin(8e6,   8e0),300
set arrow 22 from fmin(8e6,  64e0),80e3 to fmin(8e6,  64e0),300
set arrow 23 from fmin(8e6, 256e0),80e3 to fmin(8e6, 256e0),300
set arrow 24 from fmin(8e6,1024e0),80e3 to fmin(8e6,1024e0),300
set label 25 '$f_{min}$ 8bit' at 1600e0,8e3 rotate by 90.0 front

set label 30 '$f_{OC}=\frac{f_{clk}}{2N(1+OCR)}$' at 400e3,100e-3 front
set label 31 '$\Delta f_{OC}=f_{OC} \Bigg(1-\frac{f_{clk}}{f_{clk}+2Nf_{OC}}\Bigg)$' at 200e3,10e-3 front


plot	OCRnA(8e6,   1e0,x) axes x1y1 with lines title "OCRn N=1"    lw 3 lt 1, \
	DfOC( 8e6,   1e0,x) axes x1y2 with lines title "DfOC N=1"    lw 3 lt 1, \
	OCRnA(8e6,   8e0,x) axes x1y1 with lines title "OCRn N=8"    lw 3 lt 2, \
	DfOC( 8e6,   8e0,x) axes x1y2 with lines title "DfOC N=8"    lw 3 lt 2, \
	OCRnA(8e6,  64e0,x) axes x1y1 with lines title "OCRn N=64"   lw 3 lt 3, \
	DfOC( 8e6,  64e0,x) axes x1y2 with lines title "DfOC N=64"   lw 3 lt 3, \
	OCRnA(8e6, 256e0,x) axes x1y1 with lines title "OCRn N=256"  lw 3 lt 4, \
	DfOC( 8e6, 256e0,x) axes x1y2 with lines title "DfOC N=256"  lw 3 lt 4, \
	OCRnA(8e6,1024e0,x) axes x1y1 with lines title "OCRn N=1024" lw 3 lt 5, \
	DfOC( 8e6,1024e0,x) axes x1y2 with lines title "DfOC N=1024" lw 3 lt 5, \
	256e0 axes x1y1 with filledcurves y1=200e3 notitle, \
	65536e0 axes x1y1 with filledcurves y1=200e3 notitle


